MockModelDefinition class

Reusable schema definition for generated mock records.

Constructors

MockModelDefinition({required String name, required Map<String, MockFieldDefinition> fields})
Creates a named model definition.

Properties

fields Map<String, MockFieldDefinition>
Field definitions keyed by field name.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Model name as defined in YAML.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited