hasExplicitPayload property
bool
get
hasExplicitPayload
Returns true when the response explicitly provides a payload source.
Implementation
bool get hasExplicitPayload => file != null || body != null;
Returns true when the response explicitly provides a payload source.
bool get hasExplicitPayload => file != null || body != null;