isStateful property
bool
get
isStateful
Returns true when the route is backed by a mutable in-memory store.
Implementation
bool get isStateful => action != null && store != null;
Returns true when the route is backed by a mutable in-memory store.
bool get isStateful => action != null && store != null;