MockStoreDefinition class

Backing store definition for generated records.

Constructors

MockStoreDefinition({required String name, required String model, required int count, required String primaryKey})
Creates a store definition.

Properties

count int
Number of initial records to generate.
final
hashCode int
The hash code for this object.
no setterinherited
model String
Model used to seed new records.
final
name String
Store name as defined in YAML.
final
primaryKey String
Identifier field used by get, update, and delete actions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited