TemplateEngine constructor
TemplateEngine({
- Random? random,
Creates a template engine with an optional random source.
Implementation
TemplateEngine({Random? random}) : _random = random ?? Random();
Creates a template engine with an optional random source.
TemplateEngine({Random? random}) : _random = random ?? Random();