MockConfig class

Parsed representation of a mock.yaml file.

Constructors

MockConfig({required String sourcePath, required List<MockRoute> routes})
Creates a parsed mock configuration.

Properties

hashCode int
The hash code for this object.
no setterinherited
routes List<MockRoute>
Route definitions loaded from the YAML document.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourcePath String
Absolute or normalized source path of the loaded YAML file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited