MockFieldDefinition class
Field specification inside a reusable model.
Constructors
Properties
- count → int?
-
Optional item count for list-valued fields.
final
- example → Object?
-
Optional static example value.
final
- format → String?
-
Output format for date generation.
final
- from → DateTime?
-
Optional lower bound for date generation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- items → MockFieldDefinition?
-
Optional item definition for array-valued fields.
final
- max → num?
-
Optional upper bound for numeric generators.
final
- min → num?
-
Optional lower bound for numeric generators.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → DateTime?
-
Optional upper bound for date generation.
final
- type → String
-
Built-in field type or nested model name.
final
-
values
→ List<
Object?> ? -
Optional enum values for deterministic selection.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited