MockRoute class
A single route entry declared in mock.yaml.
Constructors
- MockRoute({required String path, required String method, required MockResponse response})
- Creates a route with an HTTP method, path, and response.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
HTTP method for the route.
final
- normalizedPath → String
-
Path normalized for runtime matching.
no setter
- path → String
-
Raw route path as declared in YAML.
final
- response → MockResponse
-
Response configuration for the route.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited