YamlConfigParser class
Parses and validates mock.yaml route configuration.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseFile(
String configPath) → Future< MockConfig> - Loads, parses, and validates a YAML file from disk.
-
parseString(
String content, {String sourcePath = 'mock.yaml'}) → MockConfig - Parses and validates YAML content already loaded into memory.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited