FlutterMockServer class
Local Shelf-based mock server backed by mock.yaml route definitions.
Constructors
- FlutterMockServer({required String configPath, String host = 'localhost', int port = 8080, YamlConfigParser? parser, TemplateEngine? templateEngine, Random? random})
- Creates a mock server instance for the provided config file and bind target.
Properties
- configPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- port → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> - Starts the HTTP server and begins watching the config file for changes.
-
stop(
) → Future< void> - Stops the HTTP server and cancels file watching.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited