TemplateEngine class
Expands template placeholders and generates model-backed data.
Constructors
- TemplateEngine({Random? random})
- Creates a template engine with an optional random source.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateModel(
MockModelDefinition model, Map< String, MockModelDefinition> models) → Map<String, Object?> - Generates a record from a reusable model definition.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Object? value, {TemplateContext context = const TemplateContext()}) → Object? - Recursively renders placeholders within strings, maps, and lists.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited