TemplateEngine class
Expands template placeholders in inline and file-based mock responses.
Constructors
- TemplateEngine({Random? random})
- Creates a template engine with an optional random source.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Object? value) → Object? - Recursively renders placeholders within strings, maps, and lists.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited